Module: Philiprehberger::HttpClient::Retries
- Included in:
- Connection
- Defined in:
- lib/philiprehberger/http_client/retries.rb
Overview
Retry logic extracted from Connection to keep module length manageable.
Retry logic extracted from Connection to keep module length manageable.